Geodesic calculations
=====================

This module defines the Geodesic class which can interface with the Proj
geodesic functions. See the `Proj geodesic page`_ for more background
information.

.. _Proj geodesic page: https://proj4.org/geodesic.html

.. autoclass:: cartopy.geodesic.Geodesic
    :members:
